local VERSION = tonumber(("$Revision: 394 $"):match("%d+"))

local QuestsFu = QuestsFu
local QuestsFu_Givers = QuestsFu:NewModule("Givers", "AceEvent-2.0", "AceHook-2.1", "AceConsole-2.0")
if QuestsFu.revision < VERSION then
	QuestsFu.version = "r" .. VERSION
	QuestsFu.revision = VERSION
	QuestsFu.date = ("$Date: 2009-04-17 00:15:08 +0000 (Fri, 17 Apr 2009) $"):match("%d%d%d%d%-%d%d%-%d%d")
end

local quixote = LibStub("LibQuixote-2.0")

local L = AceLibrary("AceLocale-2.2"):new("QuestsFu_Givers")

QuestsFu_Givers.lname = L["Givers"]
QuestsFu_Givers.desc = L["Record who initiated a quest"]

function QuestsFu_Givers:OnInitialize()
	self.db = QuestsFu:AcquireDBNamespace("Givers")
	QuestsFu:RegisterDefaults("Givers", "char", {
		questgivers = {},
	})
end

function QuestsFu_Givers:OnEnable()
	if quixote.firstDone then
		self:Hook("AcceptQuest", true)
		quixote.RegisterCallback(self, "Quest_Lost")

		--Check various bits of saved info for continuing validity
		-- Make sure that we haven't lost a quest whose questgiver we're remembering.
		for name,text in pairs(self.db.char.questgivers) do
			if not quixote:GetQuest(name) then
				self.db.char.questgivers[name] = nil
			end
		end
	else
		quixote.RegisterCallback(self, "Ready", function() self:OnEnable() end)
	end
end

function QuestsFu_Givers:AcceptQuest()
	if (not UnitName("npc")) or UnitIsPlayer("npc") then
		self.db.char.questgivers[GetTitleText()] = L["Item or other player"]
	else
		local x,y = GetPlayerMapPosition("player")
		self.db.char.questgivers[GetTitleText()] = L["%s in %s (%d,%d)"]:format(UnitName('npc'), GetZoneText(), floor(x*100), floor(y*100))
	end
	return self.hooks["AcceptQuest"]()
end

function QuestsFu_Givers:Quest_Lost(event, name, id)
	self.db.char.questgivers[name] = nil
end

